/* TTMPErr.c
 *
 * Descriptions of TTMP error codes.
 *
 * Copyright (C) 2005-2006 TomTom BV <http://www.tomtom.com/>
 * Author 0: Dimitry Andric <dimitry.andric@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2
 * as published by the Free Software Foundation.
 */

#include "TTMP.h"
#include "TTMPPlat.h"

int TTMPErrorString(int err, char *buf, size_t size)
{
	int n;

	switch (err) {
	case TTMP_ERR_NONE:     n = snprintf(buf, size, "No error"); break;
	case TTMP_ERR_INTERNAL: n = snprintf(buf, size, "Internal error"); break;
	case TTMP_ERR_SVRNULL:  n = snprintf(buf, size, "NULL server passed"); break;
	case TTMP_ERR_SVRINVAL: n = snprintf(buf, size, "Invalid server passed"); break;
	case TTMP_ERR_CONNULL:  n = snprintf(buf, size, "NULL connection passed"); break;
	case TTMP_ERR_CONINVAL: n = snprintf(buf, size, "Invalid connection passed"); break;
	case TTMP_ERR_MSGNULL:  n = snprintf(buf, size, "NULL message passed"); break;
	case TTMP_ERR_MSGINVAL: n = snprintf(buf, size, "Invalid message passed"); break;
	case TTMP_ERR_ARGUMENT: n = snprintf(buf, size, "Invalid other argument"); break;
	case TTMP_ERR_NOMEMORY: n = snprintf(buf, size, "Out of memory"); break;
	case TTMP_ERR_TIMEOUT:  n = snprintf(buf, size, "Timeout elapsed"); break;
	case TTMP_ERR_INCOMPAT: n = snprintf(buf, size, "Client and server version incompatible"); break;
	case TTMP_ERR_NOSERVER: n = snprintf(buf, size, "No such server"); break;
	case TTMP_ERR_NOCONN:   n = snprintf(buf, size, "No such connection"); break;
	case TTMP_ERR_NOMSG:    n = snprintf(buf, size, "No such message"); break;
	case TTMP_ERR_NOFIELD:  n = snprintf(buf, size, "No such field"); break;
	case TTMP_ERR_OVERFLOW: n = snprintf(buf, size, "Caller buffer too small"); break;
	case TTMP_ERR_NOTIMPL:  n = snprintf(buf, size, "Not implemented"); break;
	case TTMP_ERR_SYSTEM:   n = snprintf(buf, size, "System call error %d", socket_errno); break;
	case TTMP_ERR_NOLISTEN: n = snprintf(buf, size, "Server not yet listening"); break;
	case TTMP_ERR_NOTCONN:  n = snprintf(buf, size, "Not connected"); break;
	case TTMP_ERR_MSGCORR:  n = snprintf(buf, size, "Messsage corrupt"); break;
	case TTMP_ERR_PROTOVER: n = snprintf(buf, size, "Incompatible protocol version"); break;
	case TTMP_ERR_DISCONN:  n = snprintf(buf, size, "Already connected, disconnect first"); break;
	case TTMP_ERR_CONNEOF:  n = snprintf(buf, size, "Connection EOF (peer disconnected)"); break;
	default:                n = snprintf(buf, size, "Unknown TTMP error %d", err); break;
	}

	if (n < 0)
		return TTMP_ERR_SYSTEM;
	if ((size_t) n >= size)
		return TTMP_ERR_OVERFLOW;

	return TTMP_ERR_NONE;
}

/* EOF */
