/* TTMPMsg.h
 *
 * Private TTMPMessage declarations.
 *
 * Copyright (C) 2005-2006 TomTom BV <http://www.tomtom.com/>
 * Author 0: Dimitry Andric <dimitry.andric@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2
 * as published by the Free Software Foundation.
 */

#ifndef INCLUDED_TTMPMSG_H
#define INCLUDED_TTMPMSG_H

#include "TTMP.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define TTMP_MSG_MAGIC 0x254d68ea

#define TTMP_FT_Int8   1
#define TTMP_FT_Uint8  2
#define TTMP_FT_Int16  3
#define TTMP_FT_Uint16 4
#define TTMP_FT_Int32  5
#define TTMP_FT_Uint32 6
#define TTMP_FT_Real32 7
#define TTMP_FT_Real64 8
#define TTMP_FT_Real   9
#define TTMP_FT_Bool   10
#define TTMP_FT_Chr    11
#define TTMP_FT_UniChr 12
#define TTMP_FT_Long64 13
#define TTMP_FT_Str    14
#define TTMP_FT_UniStr 15
#define TTMP_FT_Binary 16

#define TTMP_FS_Int8   sizeof(TInt8)
#define TTMP_FS_Uint8  sizeof(TUint8)
#define TTMP_FS_Int16  sizeof(TInt16)
#define TTMP_FS_Uint16 sizeof(TUint16)
#define TTMP_FS_Int32  sizeof(TInt32)
#define TTMP_FS_Uint32 sizeof(TUint32)
#define TTMP_FS_Real32 sizeof(TReal32)
#define TTMP_FS_Real64 sizeof(TReal64)
#define TTMP_FS_Real   sizeof(TReal)
#define TTMP_FS_Bool   sizeof(TBool)
#define TTMP_FS_Chr    sizeof(TChr)
#define TTMP_FS_UniChr sizeof(TUniChr)
#define TTMP_FS_Long64 sizeof(TLong64)
#define TTMP_FS_Str    sizeof(TStr)
#define TTMP_FS_UniStr sizeof(TUniStr)
#define TTMP_FS_Binary sizeof(TBinary)

typedef union uTTMPValue {
	TInt8 Int8;
	TUint8 Uint8;
	TInt16 Int16;
	TUint16 Uint16;
	TInt32 Int32;
	TUint32 Uint32;
	TReal32 Real32;
	TReal64 Real64;
	TReal Real;
	TBool Bool;
	TChr Chr;
	TUniChr	UniChr;
	TLong64 Long64;
	void *data;
} TTMPValue;

typedef struct sTTMPField {
	TTMPFieldName name;
	TUint8 type;
	TUint32 size;
	TTMPValue val;
} TTMPField;

struct sTTMPMessage {
	TUint32 magic;
	TUint32 numfields;
	TUint32 maxfields;
	TTMPField *fields;
};

int TTMPMessageMarshal(cTTMPMessage msg, TUint8 **buf, TUint32 *size);
int TTMPMessageUnmarshal(const TUint8 *buf, TUint32 size, TTMPMessage *msg);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* INCLUDED_TTMPMSG_H */

/* EOF */
