/* hexdump.c
 *
 * Dump some binary data.
 *
 * Copyright (C) 2005-2006 TomTom BV <http://www.tomtom.com/>
 * Author 0: Dimitry Andric <dimitry.andric@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2
 * as published by the Free Software Foundation.
 */

#include <ctype.h>
#include "hexdump.h"
#include "TTMPPlat.h"

void hexdump(FILE *fp, const void *buf, size_t size)
{
	const size_t ROWSIZE = 16;
	size_t ofs;
	size_t i;
	int ch;

	for (ofs = 0; ofs < size; ofs += ROWSIZE) {
		fprintf(fp, "%08" PRINTF_SZ "X: ", ofs);
		for (i = 0; i < ROWSIZE; ++i) {
			if (ofs + i < size) {
				fprintf(fp, "%02X ", ((const unsigned char *) buf)[ofs + i]);
			} else {
				fprintf(fp, "   ");
			}
		}
		fprintf(fp, "  |");
		for (i = 0; i < ROWSIZE; ++i) {
			if (ofs + i < size) {
				ch = ((const unsigned char *) buf)[ofs + i];
				fprintf(fp, "%c", isprint(ch) ? ch : '.');
			} else {
				break;
			}
		}
		fprintf(fp, "|\n");
	}
}

#ifdef TEST

#define BUFSIZE 1234

int main(void)
{
	int i;
	unsigned char testbuf[BUFSIZE];

	for (i = 0; i < BUFSIZE; ++i)
		testbuf[i] = (unsigned char) i;

	hexdump(stdout, testbuf, BUFSIZE);

	return 0;
}

#endif /* TEST */

/* EOF */
